==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/filedesc/translations/filedesc_es_MX.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_MX">
<context>
    <name>@default</name>
    <message>
        <source>FileDesc</source>
        <translation>FileDesc</translation>
    </message>
    <message>
        <source>File with description to synchronize</source>
        <translation>Archivo con descripción para sincronizar</translation>
    </message>
    <message>
        <source>Enter here a file, which will contain descriptions to refresh by module.</source>
        <translation>Introduzca aquí un archivo, que contendrá las descripciones para actualizar por el módulo.</translation>
    </message>
    <message>
        <source>If you choose status without description, module will set it automatically to similar but with description</source>
        <translation>Si elige el estado sin descripción, el módulo lo establecerá automáticamente a similar pero con descripción</translation>
    </message>
    <message>
        <source>Allow other descriptions</source>
        <translation>Permitir otras descripciones</translation>
    </message>
    <message>
        <source>Allows you to set some custom description manualy, until file contents does not change</source>
        <translation>Le permite establecer alguna descripción personalizada manualmente, mientras el contenido del archivo no cambie</translation>
    </message>
    <message>
        <source>Behavior</source>
        <translation>Comportamiento</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descripción</translation>
    </message>
    <message>
        <source>Always add description to status</source>
        <translation>Siempre agregar descripción al estado</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/filedesc/translations/filedesc_es_MX.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_MX" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>FileDesc</source>
        <translation>FileDesc</translation>
    </message>
    <message>
        <source>File with description to synchronize</source>
        <translation>Archivo con descripción para sincronizar</translation>
    </message>
    <message>
        <source>Enter here a file, which will contain descriptions to refresh by module.</source>
        <translation>Introduzca aquí un archivo, que contendrá las descripciones para actualizar por el módulo.</translation>
    </message>
    <message>
        <source>If you choose status without description, module will set it automatically to similar but with description</source>
        <translation>Si elige el estado sin descripción, el módulo lo establecerá automáticamente a similar pero con descripción</translation>
    </message>
    <message>
        <source>Allow other descriptions</source>
        <translation>Permitir otras descripciones</translation>
    </message>
    <message>
        <source>Allows you to set some custom description manualy, until file contents does not change</source>
        <translation>Le permite establecer alguna descripción personalizada manualmente, mientras el contenido del archivo no cambie</translation>
    </message>
    <message>
        <source>Behavior</source>
        <translation>Comportamiento</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descripción</translation>
    </message>
    <message>
        <source>Always add description to status</source>
        <translation>Siempre agregar descripción al estado</translation>
    </message>
</context>
</TS>
